@@ -64,7 +64,8 @@ class LineClient(LineAPI):
         if authToken:
             self.authToken = self._headers['X-Line-Access'] = authToken
 
-            self.ready()
+            self.tokenLogin()
+            #self.ready()
         else:
             if EMAIL_REGEX.match(id):
                 self.provider = Provider.LINE # LINE
